diff --git a/plugins/display_renderers/panels_renderer_standard.class.php b/plugins/display_renderers/panels_renderer_standard.class.php
index a6cf0d7..00a9681 100644
--- a/plugins/display_renderers/panels_renderer_standard.class.php
+++ b/plugins/display_renderers/panels_renderer_standard.class.php
@@ -419,12 +419,12 @@ class panels_renderer_standard {
    * @see drupal_add_css
    */
   function add_css($filename, $type = 'module', $media = 'all', $preprocess = TRUE) {
-    $path = file_create_path($filename);
     switch ($this->meta_location) {
       case 'standard':
-        if ($path) {
-          // Use CTools CSS add because it can handle temporary CSS in private
-          // filesystem.
+        if (file_check_location($filename, file_directory_path())) {
+          // If the file is located in the files directory, use
+          // ctools_css_add_css() because it can handle temporary CSS in the
+          // private filesystem.
           ctools_include('css');
           ctools_css_add_css($filename, $type, $media, $preprocess);
         }
